from pymatgen.core import Structure
from pymatgen.symmetry.analyzer import SpacegroupAnalyzer

from atomate2.common.schemas.elastic import ElasticDocument
from atomate2.forcefields.flows.elastic import ElasticMaker
#from atomate2.forcefields.jobs import CHGNetRelaxMaker, MACERelaxMaker

from atomate2.forcefields.jobs import MACERelaxMaker
from mace.calculators import MACECalculator, mace_mp
#from chgnet.model.dynamics import CHGNetCalculator

import os

try:
  os.system("rm -rf job_*")
except:
  pass
  
##calculator = MACECalculator(model_path='/content/checkpoints/MACE_model_run-123.model',dispersion=False,default_dtype="float64",device='cuda')
#calculator = mace_mp(model="medium",device='cuda',default_dtype="float64") ###,dispersion=False) ###,default_dtype="float64",device='cuda')
#calculator = SevenNetCalculator("7net-0_11July2024", device='cuda')  # 7net-0, SevenNet-0, 7net-0_22May2024, 7net-0_11July2024 ...

structure =  Structure.from_file("TiZrHfNbTa.cif") 

structure= SpacegroupAnalyzer(structure).get_primitive_standard_structure()

common_kwds = {
        "model_kwargs": {"model": "medium", "default_dtype": "float64"},
        "relax_kwargs": {"fmax": 0.00001},
        }
model_kwargs={"default_dtype": "float64"}
###  MACERelaxMaker   fix_symmetry: bool = False
###    symprec: float = 1e-2
elastic_flow = ElasticMaker(
    bulk_relax_maker=MACERelaxMaker(calculator_kwargs={"model":'/home5/hppi1/vvp/UPOROV/TiZrHfNbTa/USPEX/mace/MACE_swa_compiled.model',"default_dtype": "float64","device":'cuda'},relax_kwargs={"fmax": 0.00001}, relax_cell=True),
    elastic_relax_maker=MACERelaxMaker(calculator_kwargs={"model":'/home5/hppi1/vvp/UPOROV/TiZrHfNbTa/USPEX/mace/MACE_swa_compiled.model',"default_dtype": "float64","device":'cuda'}, relax_cell=False),
).make(structure)

elastic_flow.draw_graph().show()

#%%capture
from jobflow import run_locally

responses = run_locally(elastic_flow,  create_folders=True)

from jobflow import SETTINGS

store = SETTINGS.JOB_STORE
store.connect()

result = store.query_one(
    {"name": "fit_elastic_tensor"},
    properties=[
        "output.elastic_tensor",
        "output.derived_properties",
    ],
    load=True,
    sort={"completed_at": -1} # to get the latest computation
)

print(result["output"]["elastic_tensor"]["ieee_format"])

print(result["output"]["derived_properties"])
